@@ -144,9 +144,11 @@ test_that("user1: demo table works.", {
       write_report(rpt, rtfpth, output_type = "RTF")
       expect_equal(file.exists(rtfpth), TRUE)
       
-      pdfpth <- file.path(base_path, "user/user1.pdf")
-      write_report(rpt, pdfpth, output_type = "PDF")
-      expect_equal(file.exists(pdfpth), TRUE)
+      if (rmarkdown::pandoc_available("1.12.3")) {
+        pdfpth <- file.path(base_path, "user/user1.pdf")
+        write_report(rpt, pdfpth, output_type = "PDF")
+        expect_equal(file.exists(pdfpth), TRUE)
+      }
     }
   
   } else 
@@ -363,9 +365,12 @@ test_that("user3: listings works.", {
     write_report(rpt, rtfpth, output_type = "RTF")
     expect_equal(file.exists(rtfpth), TRUE)
     
-    pdfpth <- file.path(base_path, "user/user3.pdf")
-    write_report(rpt, pdfpth, output_type = "PDF")
-    expect_equal(file.exists(pdfpth), TRUE)
+    if (rmarkdown::pandoc_available("1.12.3")) {
+      pdfpth <- file.path(base_path, "user/user3.pdf")
+      write_report(rpt, pdfpth, output_type = "PDF")
+      expect_equal(file.exists(pdfpth), TRUE)
+    }
+    
   } else
     expect_equal(TRUE, TRUE)
 })
@@ -512,10 +517,12 @@ test_that("user4: Adverse Events table works.", {
     expect_equal(file.exists(rtfpth), TRUE)
     #print(res)
     
-    pdfpth <- file.path(base_path, "user/user4.pdf")
-    res <- write_report(rpt, pdfpth, output_type = "PDF")
-    expect_equal(file.exists(pdfpth), TRUE)
-    #print(res)
+    if (rmarkdown::pandoc_available("1.12.3")) {
+      pdfpth <- file.path(base_path, "user/user4.pdf")
+      res <- write_report(rpt, pdfpth, output_type = "PDF")
+      expect_equal(file.exists(pdfpth), TRUE)
+      #print(res)
+    }
   } else
     expect_equal(TRUE, TRUE)
 })
@@ -627,8 +634,10 @@ test_that("user6: listings with page break works as expected.", {
     res <- write_report(rpt, output_type = "RTF")
     expect_equal(file.exists(res$modified_path), TRUE)
     
-    res <- write_report(rpt, output_type = "PDF")
-    expect_equal(file.exists(res$modified_path), TRUE)
+    if (rmarkdown::pandoc_available("1.12.3")) {
+      res <- write_report(rpt, output_type = "PDF")
+      expect_equal(file.exists(res$modified_path), TRUE)
+    }
   
   } else
     expect_equal(TRUE, TRUE)
